@@ -347,13 +347,17 @@ main (int argc, char **argv)
 
 		g_log_set_default_handler (log_handler, NULL);
 
+		/* This call is needed to set the journal's filename */
+		tracker_db_journal_init (NULL);
+
 		/* Clean up */
-		if (!tracker_db_manager_init (TRACKER_DB_MANAGER_REMOVE_ALL, NULL, FALSE, NULL)) {
+		if (!tracker_db_manager_init (TRACKER_DB_MANAGER_REMOVE_ALL, NULL, FALSE)) {
 			return EXIT_FAILURE;
 		}
 
 		tracker_db_manager_remove_all (hard_reset);
 		tracker_db_manager_shutdown ();
+		tracker_db_journal_shutdown ();
 
 		/* Unset log handler */
 		g_log_remove_handler (NULL, log_handler_id);
