@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2009, Nokia
  *
@@ -23,9 +22,11 @@
 
 #include <glib.h>
 
-#ifdef __cplusplus
-extern "C"
-#endif
-gchar* extract_msword_content (const gchar *uri, gint max_words);
+G_BEGIN_DECLS
+
+gchar* extract_msword_content (const gchar *uri, 
+                               gint         max_words);
+
+G_END_DECLS
 
 #endif /* __TRACKERD_MSWORD_H__ */
