@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2009, Nokia (urho.konttori@nokia.com)
  *
@@ -71,18 +70,18 @@ test_sparql_query (gconstpointer test_data)
 
 	tracker_data_manager_init (TRACKER_DB_MANAGER_FORCE_REINDEX,
 	                           data_prefix,
-	                           NULL, NULL);
+	                           NULL);
 
 	/* load data / perform updates */
 
 	update_filename = g_strconcat (test_prefix, "-data.rq", NULL);
 	g_file_get_contents (update_filename, &update, NULL, &error);
-	g_assert (error == NULL);
+	g_assert_no_error (error);
 
 	tracker_data_begin_transaction ();
 	tracker_data_update_sparql (update, &error);
 	tracker_data_commit_transaction ();
-	g_assert (error == NULL);
+	g_assert_no_error (error);
 
 	g_free (update_filename);
 	g_free (update);
@@ -92,14 +91,14 @@ test_sparql_query (gconstpointer test_data)
 	for (i = 1; i <= test_info->number_of_queries; i++) {
 		query_filename = g_strdup_printf ("%s-%d.rq", test_prefix, i);
 		g_file_get_contents (query_filename, &query, NULL, &error);
-		g_assert (error == NULL);
+		g_assert_no_error (error);
 
 		results_filename = g_strdup_printf ("%s-%d.out", test_prefix, i);
 		g_file_get_contents (results_filename, &results, NULL, &error);
-		g_assert (error == NULL);
+		g_assert_no_error (error);
 
 		result_set = tracker_data_query_sparql (query, &error);
-		g_assert (error == NULL);
+		g_assert_no_error (error);
 
 		/* compare results with reference output */
 
@@ -159,7 +158,7 @@ test_sparql_query (gconstpointer test_data)
 			quoted_command_line = g_shell_quote (command_line);
 			shell = g_strdup_printf ("sh -c %s", quoted_command_line);
 			g_spawn_command_line_sync (shell, &diff, NULL, NULL, &error);
-			g_assert (error == NULL);
+			g_assert_no_error (error);
 
 			g_error ("%s", diff);
 
